==> panelPomp_1.1.tgz: panelPomp/help/macros/cite.Rd <==
% unlike in latex, new lines within \newcommand end the command (even using %)
\newcommand{\arulampalam2002}{Arulampalam, M. S., Maskell, S., Gordon, N. and Clapp, T. (2002) A Tutorial on Particle Filters for Online Nonlinear/Non-Gaussian Bayesian Tracking. \emph{IEEE Trans. Sig. Proc.}, \bold{50}(2), 174--188. \doi{https://doi.org/10.1109/78.978374}}

\newcommand{\breto2020}{\Breto, C., Ionides, E. L. and King, A. A. (2020) Panel Data Analysis via Mechanistic Models. \emph{Journal of the American Statistical Association}, \bold{115}(531), 1178--1188. \doi{https://doi.org/10.1080/01621459.2019.1604367}}

\newcommand{\ionides2006}{Ionides, E. L., \Breto, C. and King, A. A. (2006) Inference for nonlinear dynamical systems. \emph{Proceedings of the National Academy of Sciences}, \bold{103}(49), 18438--18443. \doi{https://doi.org/10.1073/pnas.0603181103}}

\newcommand{\ionides2011}{Ionides, E. L., Bhadra, A., \Atchade, Y. and King, A. A. (2011) Iterated filtering. \emph{Annals of Statistics}, \bold{39}(3), 1776--1802. \doi{https://doi.org/10.1214/11-AOS886}}

\newcommand{\ionides2015}{Ionides, E. L., Nguyen, D., \Atchade, Y., Stoev, S. and King, A. A. (2015) Inference via iterated, perturbed Bayes maps. \emph{Proceedings of the National Academy of Sciences}, \bold{112}(3), 719--724. \doi{https://doi.org/10.1073/pnas.1410597112}}

\newcommand{\king2016}{King, A. A., Nguyen, D. and Ionides, E. L. (2016) Statistical inference for partially observed Markov processes via the package \pkg{pomp}. \emph{Journal of Statistical Software} \bold{69}(12), 1--43. \acronym{DOI}: 10.18637/jss.v069.i12. An updated version of this paper is available on the \href{https://kingaa.github.io/pomp/docs.html}{package website}.}

\newcommand{\romeroseverson2015}{Romero-Severson, E.O., Volz, E., Koopman, J.S., Leitner, T. and Ionides, E.L. (2015) Dynamic variation in sexual contact rates in a cohort of HIV-negative gay men. \emph{American journal of epidemiology}, \bold{182}(3), 255--262. \doi{http://doi.org/10.1093/aje/kwv044}}

\newcommand{\sisson2007}{Sisson, S. A., Fan, Y. and Tanaka, M. M. (2007) Sequential Monte Carlo without likelihoods. \emph{Proceedings of the National Academy of Sciences}, \bold{104}(6), 1760--1765. \doi{http://doi.org/10.1073/pnas.0607208104}}

\newcommand{\sisson2009}{Sisson, S. A., Fan, Y. and Tanaka, M. M. (2009) Correction for Sisson et al., Sequential Monte Carlo without likelihoods. \emph{Proceedings of the National Academy of Sciences}, \bold{106}(39), 16889. \doi{http://doi.org/10.1073/pnas.0908847106}}

\newcommand{\tavare1997}{Tavare, S., Balding, D. J., Griffiths, R. C. and Donnelly, P. (1997) Inferring Coalescence Times from DNA Sequence Data. \emph{Genetics}, \bold{145}(2), 505--518. \doi{https://doi.org/10.1093/genetics/145.2.505}}

\newcommand{\vittinghoff1999}{Vitinghoff, E., Douglas, J., Judon, F., McKiman, D., MacQueen, K. and Buchinder, S.P. (1999) Per-contact risk of human immunodificiency virus tramnsmision between male sexual partners. \emph{American journal of epidemiology}, \bold{150}(3), 306--311. \doi{https://doi.org/10.1093/oxfordjournals.aje.a010003}}

==> panelPomp_1.7.0.0.tgz: panelPomp/help/macros/cite.Rd <==
% unlike in latex, new lines within \newcommand end the command (even using %)
\newcommand{\arulampalam2002}{Arulampalam, M. S., Maskell, S., Gordon, N. and Clapp, T. (2002) A Tutorial on Particle Filters for Online Nonlinear/Non-Gaussian Bayesian Tracking. \emph{IEEE Trans. Sig. Proc.}, \bold{50}(2), 174--188. \doi{https://doi.org/10.1109/78.978374}}

\newcommand{\breto2020}{\Breto, C., Ionides, E. L. and King, A. A. (2020) Panel Data Analysis via Mechanistic Models. \emph{Journal of the American Statistical Association}, \bold{115}(531), 1178--1188. \doi{https://doi.org/10.1080/01621459.2019.1604367}}

\newcommand{\ionides2006}{Ionides, E. L., \Breto, C. and King, A. A. (2006) Inference for nonlinear dynamical systems. \emph{Proceedings of the National Academy of Sciences}, \bold{103}(49), 18438--18443. \doi{https://doi.org/10.1073/pnas.0603181103}}

\newcommand{\ionides2011}{Ionides, E. L., Bhadra, A., \Atchade, Y. and King, A. A. (2011) Iterated filtering. \emph{Annals of Statistics}, \bold{39}(3), 1776--1802. \doi{https://doi.org/10.1214/11-AOS886}}

\newcommand{\ionides2015}{Ionides, E. L., Nguyen, D., \Atchade, Y., Stoev, S. and King, A. A. (2015) Inference via iterated, perturbed Bayes maps. \emph{Proceedings of the National Academy of Sciences}, \bold{112}(3), 719--724. \doi{https://doi.org/10.1073/pnas.1410597112}}

\newcommand{\king2016}{King, A. A., Nguyen, D. and Ionides, E. L. (2016) Statistical inference for partially observed Markov processes via the package \pkg{pomp}. \emph{Journal of Statistical Software} \bold{69}(12), 1--43. \acronym{DOI}: 10.18637/jss.v069.i12. An updated version of this paper is available on the \href{https://kingaa.github.io/pomp/docs.html}{package website}.}

\newcommand{\romeroseverson2015}{Romero-Severson, E.O., Volz, E., Koopman, J.S., Leitner, T. and Ionides, E.L. (2015) Dynamic variation in sexual contact rates in a cohort of HIV-negative gay men. \emph{American journal of epidemiology}, \bold{182}(3), 255--262. \doi{http://doi.org/10.1093/aje/kwv044}}

\newcommand{\sisson2007}{Sisson, S. A., Fan, Y. and Tanaka, M. M. (2007) Sequential Monte Carlo without likelihoods. \emph{Proceedings of the National Academy of Sciences}, \bold{104}(6), 1760--1765. \doi{http://doi.org/10.1073/pnas.0607208104}}

\newcommand{\sisson2009}{Sisson, S. A., Fan, Y. and Tanaka, M. M. (2009) Correction for Sisson et al., Sequential Monte Carlo without likelihoods. \emph{Proceedings of the National Academy of Sciences}, \bold{106}(39), 16889. \doi{http://doi.org/10.1073/pnas.0908847106}}

\newcommand{\tavare1997}{Tavare, S., Balding, D. J., Griffiths, R. C. and Donnelly, P. (1997) Inferring Coalescence Times from DNA Sequence Data. \emph{Genetics}, \bold{145}(2), 505--518. \doi{https://doi.org/10.1093/genetics/145.2.505}}

\newcommand{\vittinghoff1999}{Vitinghoff, E., Douglas, J., Judon, F., McKiman, D., MacQueen, K. and Buchinder, S.P. (1999) Per-contact risk of human immunodificiency virus tramnsmision between male sexual partners. \emph{American journal of epidemiology}, \bold{150}(3), 306--311. \doi{https://doi.org/10.1093/oxfordjournals.aje.a010003}}

\newcommand{\He2010}{D. He, E.L. Ionides, and A.A. King. Plug-and-play inference for disease dynamics: measles in large and small populations as a case study.  \emph{Journal of the Royal Society Interface} \bold{7}, 271--283, 2010.}

\newcommand{\Korevaar2020}{Korevaar H, Metcalf CJ, Grenfell BT. 2020 Structure, space and size: competing drivers of variation in urban and rural measles transmission. J. R. Soc. Interface 17: 20200010. http://dx.doi.org/10.1098/rsif.2020.0010}
